// Device resolutions. Can be used for device-specific customization.
var RESOLUTION_UNDEFINED = 0;
var RESOLUTION_QVGA_LANDSCAPE = 1;  // 320x240
var RESOLUTION_QVGA_PORTRAIT = 2;   // 240x320
var RESOLUTION_NHD_LANDSCAPE = 3;   // 640x360
var RESOLUTION_NHD_PORTRAIT = 4;    // 360x640
var RESOLUTION_HOME_SCREEN = 5;     // less than 75 % of the resolutions above
var resolution = RESOLUTION_UNDEFINED;

window.onload = init;
window.onresize = windowResized;

// Initializes the widget
function init() {
    // Call windowResized manually here to ensure the correct layout
    windowResized(); hide();

    // Loads the saved string into the input field if the key exists
    var savedString = widget.preferenceForKey("key2");
    if (savedString != null) {
        document.getElementById("text1").value = savedString;
    }
}



// Saves the string from the input field to persistent storage.
function saveString( ) {
    widget.setPreferenceForKey(document.getElementById("text1").value, "key2");
    alert("Your note has been saved.");
}

// Called when the window is resized
function windowResized() {
    printString("");
}

// Called when the window is resized
function windowResized() {
    var prevResolution = resolution;
    
    // Detect the new resolution
    detectResolution();

    if (resolution == RESOLUTION_NHD_PORTRAIT) {
        setActiveStyleSheet("NHD Portrait");
    } else if (resolution == RESOLUTION_NHD_LANDSCAPE) {
        setActiveStyleSheet("NHD Landscape");    
    } else if (resolution == RESOLUTION_HOME_SCREEN) {
        setActiveStyleSheet("Home Screen");
    } else if (resolution == RESOLUTION_UNDEFINED) {
        // TODO: Error handling
    }
}

// Detects the resolution of the device
function detectResolution() {
    var screenWidth = screen.width;
    var screenHeight = screen.height;
    var windowWidth = window.innerWidth;
    var windowHeight = window.innerHeight;
    
    if (windowHeight < (0.75 * screenHeight) ||
        windowWidth < (0.75 * screenWidth)) {
        // If the window width or height is less than 75 % of the screen width
        // or height, we assume the home screen view should be active
        resolution = RESOLUTION_HOME_SCREEN;    
    } else if (screenWidth == 360 && screenHeight == 640) {
        resolution = RESOLUTION_NHD_PORTRAIT;
    } else if (screenWidth == 640 && screenHeight == 360) {
        resolution = RESOLUTION_NHD_LANDSCAPE;
    } else {
        resolution = RESOLUTION_UNDEFINED;
    }
}


function hide() {
    window.menu.hideSoftkeys();
}
